<?
	/*
	   A class to handle templates by rip@prescient.co.za:
	   
	   variables in templates must be surrounded by a double pipe (||),
	   ||test_variable|| is an example of a variable called test_variable.
	   
	   Variables:
	   $text     -> The text that the template currently points to
		$filename -> Filesystem file that the Template contains
		$debug    -> Set this to have debug stuff printed on top of 
		             $this->text
	   $version  -> The version as provided by CVS
		
		
	   Methods:
	   Template    -> constructor
		ReadFile    -> Reads a file into $this->text
		Comment     -> Insert a comment into $this->text (html style)
		Send        -> Sends $this->text to STDOUT
		Email       -> Emails $this->text to someone, after removing
		               all PHP and HTML tags
		Replace     -> Replace a template variable with a value
		Set         -> Alias for Replace
		Clean			-> Removes any unused variables
		pg_DropDown -> Postgres specific function to create drop downs
		               from SQL queries
		pg_Table    -> Postgres specific function to create a table
		               containing a SQL query
		Error       -> Code to print a error message and exit

	 */

	class Template {
		
		var $text;
		var $filename;
		var $debug = FALSE;
		var $version = '$Id: html-lib.php,v 1.1.1.1 2004/08/28 10:11:19 rip Exp $';
		
	    // Initiate the class with a file if its specified
		function Template ($filename) {

			if ($filename <> "") {
				$this->ReadFile ($filename);
			}
		}

	   // Prints a Error message and exits
		function Error ($message) {
			$t  = "<TITLE>Error: $message</TITLE>";
			$t .= "<BODY BGCOLOR=\"#ffffff\">\n";
			$t .= "<CENTER><H2>An Error occurred in your application</H2></CENER>\n";
			$t .= "<BR><BR>";
			$t .= "<CENTER><TABLE>\n";
			$t .= "\t<TR BGCOLOR=\"#006666\"><TD><FONT COLOR=\"#ffffff\">Your application has caused an unrecoverable error</FONT></TD></TR>\n";
			$t .= "\t<TR><TD>$message</TD></TR>\n";
			$t .= "</TABLE>\n";
				
			echo $t;
			exit();
		}

	   // Reads a file and returns it as one big string
		function ReadFile ($filename) {
			
			if (!file_exists($filename)) {
				$this->Error ("File not found: $filename");
			}

			$this->filename = $filename;
			$this->text = "";

			if (! ($fd = @fopen ($filename, "r"))) { 
				$this->Error ("Cant open file: $php_errormsg");
			}

			while ($buffer = fgets($fd, 4096)) {
				$this->text .= $buffer;
			}
		 	fclose ($fd);
			
			if ($this->debug == TRUE) {
				$this->Comment ("Read template from " . $filename . " by php Template class version " . $this->version);
			}
		}
		
	   // Places a comment at the top of the $text in html comment form
		function Comment ($comment) {
			$this->text = "<!-- $comment -->\n" . $this->text;
		}

	   // Prints the text contained in a template
		function Send () {
			printf ("%s",  $this->text);
		}
		
	   // Emails the text in a template after stripping off all html and
	   // php tags
		function Email ($from, $to, $subject) {
			$url = "http://" . $GLOBALS["SERVER_NAME"] . $GLOBALS["REQUEST_URI"];
			$headers = "From: $from\nReply-To: $from\nX-URL: $url";
			
			if (mail ($to, $subject, strip_tags($this->text), $headers) == TRUE) {
				return TRUE;
			} else {
				return FALSE;
			}
		}
		
	   // Replace a variable in the template with text
		function Replace ($var, $text) {
			$var = "\|\|" . $var . "\|\|";
			$this->text = eregi_replace($var, $text, $this->text);
		}
		
		function Set ($var, $text) {
			$this->Replace ($var, $text);
		}

		// Take out all unused variable names in the html
		function Clean() {
			$this->text = eregi_replace("\|\|.+\|\|", "", $this->text);
		}

	   // Replace ||i_name|| with a table based on $sql:
	   // usage:
	   //   $templ->pg_Table("SELECT one, two FROM TABLE", "i_name", 
	   //                         "#ffffff", "#000000");
	   //
	   //   ||i_name|| will have a table with 4 entries per row, containing
	   //   radio buttons with value's of one and text's of two, two will 
	   //   be in color #ffffff and the table will have a background of 
	   //   #000000
		function pg_Table($sql, $i_name, $fgcolor, $bgcolor) {
			$sql_result = pg_Exec($sql);
			
			$t = "<TABLE BORDER=0 WIDTH=\"100%\">\n";

			for ($i = 0; $i < pg_NumRows($sql_result); $i++) {
				$t .= "<TR BGCOLOR=\"$bgcolor\">\n";
				for ($j = $i; $j <= $i + 3; $j++) {
					if ($j < pg_NumRows($sql_result)) {
						$row = pg_fetch_array($sql_result, $j);
						if ($row[0] == 0) {
							$checked = "CHECKED";
						} else {
							$checked = "";
						}

						$t .= "\t<TD><INPUT TYPE=RADIO VALUE=\"$row[0]\" NAME=\"$i_name\" $checked> <FONT COLOR=\"$fgcolor\">$row[1]</FONT></TD>\n";
					} else {
						$t .= "<TD> &nbsp </TD>";
					}
				}
				$i = $i + 3;
				$t .= "</TR>\n";
			}

			$t .= "</TABLE>";
			$this->Replace ($i_name, $t);
		}

		
	   // Replace ||$dd_name|| with  a drop down list based on $sql: 
	   // usage:
	   //  $dd = $templ->pg_DropDown("SELECT one, two FROM TABLE", "dd");
	   //      or
	   //  $dd = $templ->pg_DropDown("SELECT one, two FROM TABLE", "dd", 1);
	   //   
	   //   $dd will now contain the code for a drop down list with 
	   //   values of one and text of two
	   //
	   //   if there is a entry valued '0' that entry will be selected by 
	   //   default else the one specified as the last arg will.
		function pg_DropDown ($sql, $dd_name, $select = 0) {
			$sql_result = pg_Exec($sql);
			$t = "<SELECT NAME=\"" . $dd_name . "\">\n";
		
			for ($i = 0; $i < pg_NumRows($sql_result); $i++) {
				$row = pg_fetch_array($sql_result, $i);
				if ($row[0] == $selected) {
					$selected = "SELECTED";
				} else {
					$selected = "";
				}
			
				if (isset($row[1])) {
					$t .= "   <OPTION NAME=\"" . $dd_name . "\" VALUE=\"" . $row[0] . "\"" . $selected . ">" . $row[1] . "\n";
				} else {
					$t .= "   <OPTION NAME=\"" . $dd_name . "\" VALUE=\"" . $row[0] . "\"" . $selected . ">" . $row[0] . "\n";
				}
			}
			$t .= "</SELECT>\n";
		
			$this->Replace($dd_name, $t);
		}
	}
	
	/*
		General functions that aid in web development
		
		ReadFileStr -> Reads a file and returns one large string containing
							the text.
	*/

	// Reads a file and return its contents in a large string
	function ReadFileStr($filename) {
		$fh = fopen($filename, "r");
		while ($buffer = fgets($fh, 4096)) {
			$text .= $buffer;
		}

		return $text;
	}
?>
